Index

A C D E F G H I J L M N P Q R S T U V W 
All Classes and Interfaces|All Packages|Serialized Form

A

AbstractComparator - Class in com.unitvectory.jsonassertify.comparator
This class provides a skeletal implementation of the JSONComparator interface, to minimize the effort required to implement this interface.
AbstractComparator() - Constructor for class com.unitvectory.jsonassertify.comparator.AbstractComparator
Constructs a new AbstractComparator.
allJSONArrays(JSONArray) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Returns whether all elements in array are JSONArray instances.
allJSONObjects(JSONArray) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Returns whether all elements in array are JSONObject instances.
allSimpleValues(JSONArray) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Returns whether all of the elements in the given array are simple values.
appliesToPath(String) - Method in class com.unitvectory.jsonassertify.Customization
Returns true if this Customization applies to the specified path.
areNotSameDoubles(Object, Object) - Method in class com.unitvectory.jsonassertify.comparator.DefaultComparator
Checks if the provided objects are of type Number and are not equal.
areNumbers(Object, Object) - Method in class com.unitvectory.jsonassertify.comparator.DefaultComparator
Checks if the provided objects are of type Number.
arrayOfJsonObjectToMap(JSONArray, String) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Converts the provided JSONArray to a Map of JSONObjects where the key of each object is the value at uniqueKey in each object.
ArraySizeComparator - Class in com.unitvectory.jsonassertify.comparator
A JSONAssert array size comparator.
ArraySizeComparator(JSONCompareMode) - Constructor for class com.unitvectory.jsonassertify.comparator.ArraySizeComparator
Create new ArraySizeComparator.
ArrayValueMatcher<T> - Class in com.unitvectory.jsonassertify
A value matcher for arrays.
ArrayValueMatcher(JSONComparator) - Constructor for class com.unitvectory.jsonassertify.ArrayValueMatcher
Create ArrayValueMatcher to match every element in actual array against elements taken in sequence from expected array, repeating from start of expected array if necessary.
ArrayValueMatcher(JSONComparator, int) - Constructor for class com.unitvectory.jsonassertify.ArrayValueMatcher
Create ArrayValueMatcher to match specified element in actual array against first element of expected array.
ArrayValueMatcher(JSONComparator, int, int) - Constructor for class com.unitvectory.jsonassertify.ArrayValueMatcher
Create ArrayValueMatcher to match every element in specified range (inclusive) from actual array against elements taken in sequence from expected array, repeating from start of expected array if necessary.
assertEquals(String, String, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, String, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the json string provided matches the expected string.
assertEquals(String, String, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, String, String, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, String, String, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the json string provided matches the expected string.
assertEquals(String, String, String, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, String, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, String, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, String, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected string.
assertEquals(String, String, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected string.
assertEquals(String, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected string.
assertEquals(String, JSONArray, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected JSONArray.
assertEquals(String, JSONArray, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected JSONArray.
assertEquals(String, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected string.
assertEquals(String, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected string.
assertEquals(String, JSONObject, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected JSONObject.
assertEquals(String, JSONObject, JSONObject, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected JSONObject.
assertEquals(String, JSONObject, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected JSONObject.
assertEquals(JSONArray, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected JSONArray.
assertEquals(JSONArray, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided matches the expected JSONArray.
assertEquals(JSONObject, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected JSONObject.
assertEquals(JSONObject, JSONObject, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected JSONObject.
assertEquals(JSONObject, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided matches the expected JSONObject.
assertNotEquals(String, String, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, String, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the json string provided does not match the expected string.
assertNotEquals(String, String, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, String, String, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, String, String, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the json string provided does not match the expected string.
assertNotEquals(String, String, String, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, String, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, String, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, String, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected string.
assertNotEquals(String, String, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected string.
assertNotEquals(String, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected string.
assertNotEquals(String, JSONArray, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected JSONArray.
assertNotEquals(String, JSONArray, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected JSONArray.
assertNotEquals(String, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected string.
assertNotEquals(String, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected string.
assertNotEquals(String, JSONObject, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected JSONObject.
assertNotEquals(String, JSONObject, JSONObject, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected JSONObject.
assertNotEquals(String, JSONObject, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected JSONObject.
assertNotEquals(JSONArray, JSONArray, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected JSONArray.
assertNotEquals(JSONArray, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONArray provided does not match the expected JSONArray.
assertNotEquals(JSONObject, JSONObject, boolean) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected JSONObject.
assertNotEquals(JSONObject, JSONObject, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected JSONObject.
assertNotEquals(JSONObject, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONAssert
Asserts that the JSONObject provided does not match the expected JSONObject.

C

checkJsonObjectKeysActualInExpected(String, JSONObject, JSONObject, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSON string provided to the expected JSON string, and returns the results of the comparison.
checkJsonObjectKeysExpectedInActual(String, JSONObject, JSONObject, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSON object provided to the expected JSON object using provided comparator, and returns the results of the comparison.
com.unitvectory.jsonassertify - package com.unitvectory.jsonassertify
 
com.unitvectory.jsonassertify.comparator - package com.unitvectory.jsonassertify.comparator
 
compareJson(JSONString, JSONString) - Static method in class com.unitvectory.jsonassertify.JSONCompare
Compares JSONString provided to the expected JSONString, checking that the JSONString.toJSONString() are equal.
compareJSON(String, String, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONCompare
Compares JSON string provided to the expected JSON string using provided comparator, and returns the results of the comparison.
compareJSON(String, String, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONCompare
Compares JSON string provided to the expected JSON string, and returns the results of the comparison.
compareJSON(String, JSONObject, JSONObject, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.DefaultComparator
 
compareJSON(String, JSONObject, JSONObject, JSONCompareResult) - Method in interface com.unitvectory.jsonassertify.comparator.JSONComparator
Compares two JSONObjects on the provided path represented by prefix and updates the result of the comparison in the result JSONCompareResult object.
compareJSON(JSONArray, JSONArray) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSONArray provided to the expected JSONArray, and returns the results of the comparison.
compareJSON(JSONArray, JSONArray) - Method in interface com.unitvectory.jsonassertify.comparator.JSONComparator
Compares two JSONArrays and returns the result of the comparison in a JSONCompareResult object.
compareJSON(JSONArray, JSONArray, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONCompare
Compares JSON object provided to the expected JSON object using provided comparator, and returns the results of the comparison.
compareJSON(JSONArray, JSONArray, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONCompare
Compares JSONArray provided to the expected JSONArray, and returns the results of the comparison.
compareJSON(JSONObject, JSONObject) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSONObject provided to the expected JSONObject, and returns the results of the comparison.
compareJSON(JSONObject, JSONObject) - Method in interface com.unitvectory.jsonassertify.comparator.JSONComparator
Compares two JSONObjects and returns the result of the comparison in a JSONCompareResult object.
compareJSON(JSONObject, JSONObject, JSONComparator) - Static method in class com.unitvectory.jsonassertify.JSONCompare
Compares JSON object provided to the expected JSON object using provided comparator, and returns the results of the comparison.
compareJSON(JSONObject, JSONObject, JSONCompareMode) - Static method in class com.unitvectory.jsonassertify.JSONCompare
Compares JSONObject provided to the expected JSONObject, and returns the results of the comparison.
compareJSONArray(String, JSONArray, JSONArray, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.ArraySizeComparator
Expected array should consist of either 1 or 2 integer values that define maximum and minimum valid lengths of the actual array.
compareJSONArray(String, JSONArray, JSONArray, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.DefaultComparator
 
compareJSONArray(String, JSONArray, JSONArray, JSONCompareResult) - Method in interface com.unitvectory.jsonassertify.comparator.JSONComparator
Compares two JSONArrays on the provided path represented by prefix and updates the result of the comparison in the result JSONCompareResult object.
compareJSONArrayOfJsonObjects(String, JSONArray, JSONArray, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSON object provided to the expected JSON object using provided comparator, and returns the results of the comparison.
compareJSONArrayOfSimpleValues(String, JSONArray, JSONArray, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSON object provided to the expected JSON object using provided comparator, and returns the results of the comparison.
compareJSONArrayWithStrictOrder(String, JSONArray, JSONArray, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSON object provided to the expected JSON object using provided comparator, and returns the results of the comparison.
compareValues(String, Object, Object, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.CustomComparator
 
compareValues(String, Object, Object, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.DefaultComparator
 
compareValues(String, Object, Object, JSONCompareResult) - Method in interface com.unitvectory.jsonassertify.comparator.JSONComparator
Compares two Objects on the provided path represented by prefix and updates the result of the comparison in the result JSONCompareResult object.
CustomComparator - Class in com.unitvectory.jsonassertify.comparator
A JSONAssert custom comparator.
CustomComparator(JSONCompareMode, Customization...) - Constructor for class com.unitvectory.jsonassertify.comparator.CustomComparator
Constructs a new CustomComparator with the provided JSONCompareMode and Customizations.
customization(String, ValueMatcher<Object>) - Static method in class com.unitvectory.jsonassertify.Customization
Creates a new Customization instance for path and comparator.
Customization - Class in com.unitvectory.jsonassertify
Associates a custom matcher to a specific jsonpath.
Customization(String, ValueMatcher<Object>) - Constructor for class com.unitvectory.jsonassertify.Customization
Constructs a new Customization with the provided path and comparator.

D

DefaultComparator - Class in com.unitvectory.jsonassertify.comparator
This class is the default json comparator implementation.
DefaultComparator(JSONCompareMode) - Constructor for class com.unitvectory.jsonassertify.comparator.DefaultComparator
Constructs a new DefaultComparator with the provided JSONCompareMode.

E

equal(String, T, T, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.ArrayValueMatcher
 
equal(String, T, T, JSONCompareResult) - Method in interface com.unitvectory.jsonassertify.LocationAwareValueMatcher
Match actual value with expected value.
equal(T, T) - Method in class com.unitvectory.jsonassertify.ArrayValueMatcher
 
equal(T, T) - Method in class com.unitvectory.jsonassertify.RegularExpressionValueMatcher
 
equal(T, T) - Method in interface com.unitvectory.jsonassertify.ValueMatcher
Compares the two provided objects whether they are equal.

F

fail(String) - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Identify that the comparison failed
fail(String, ValueMatcherException) - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Identify that the comparison failed
fail(String, Object, Object) - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Identify that the comparison failed
failed() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Did the comparison fail?
FieldComparisonFailure - Class in com.unitvectory.jsonassertify
Models a failure when comparing two fields.
FieldComparisonFailure(String, Object, Object) - Constructor for class com.unitvectory.jsonassertify.FieldComparisonFailure
Constructs a new FieldComparisonFailure.
findUniqueKey(JSONArray) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Searches for the unique key of the expected JSON array.
formatUniqueKey(String, String, Object) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Formats a unique key for the given key, unique key, and value.

G

getActual() - Method in class com.unitvectory.jsonassertify.FieldComparisonFailure
Gets the actual value.
getActual() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Deprecated.
getActual() - Method in exception com.unitvectory.jsonassertify.ValueMatcherException
Gets the actual value
getCardinalityMap(Collection<T>) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Creates a cardinality map from coll.
getExpected() - Method in class com.unitvectory.jsonassertify.FieldComparisonFailure
Gets the expected value.
getExpected() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Deprecated.
getExpected() - Method in exception com.unitvectory.jsonassertify.ValueMatcherException
Gets the expected value
getField() - Method in class com.unitvectory.jsonassertify.FieldComparisonFailure
Gets the field that failed.
getField() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Deprecated.
getFieldFailures() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Get the list of failures on field comparisons
getFieldMissing() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Get the list of missed on field comparisons
getFieldUnexpected() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Get the list of failures on field comparisons
getKeys(JSONObject) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Collects all keys in jsonObject.
getMessage() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Result message
getObjectOrNull(JSONArray, int) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Returns the value present in the given index position.

H

hasStrictOrder() - Method in enum com.unitvectory.jsonassertify.JSONCompareMode
Strict order required

I

isExtensible() - Method in enum com.unitvectory.jsonassertify.JSONCompareMode
Is extensible
isFailureOnField() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Check if comparison failed on any particular fields
isMissingOnField() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Check if comparison failed with missing on any particular fields
isSimpleValue(Object) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Returns whether the given object is a simple value: not JSONObject and not JSONArray.
isUnexpectedOnField() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Check if comparison failed with unexpected on any particular fields
isUsableAsUniqueKey(String, JSONArray) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Looks to see if candidate field is a possible unique key across a array of objects.

J

jsonArrayToList(JSONArray) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Converts the given JSONArray to a list of Objects.
JSONAssert - Class in com.unitvectory.jsonassertify
A set of assertion methods useful for writing tests methods that return JSON.
JSONComparator - Interface in com.unitvectory.jsonassertify.comparator
Interface for comparison handler.
JSONCompare - Class in com.unitvectory.jsonassertify
Provides API to compare two JSON entities.
JSONCompareMode - Enum in com.unitvectory.jsonassertify
These different modes define different behavior for the comparison of JSON for testing.
JSONCompareResult - Class in com.unitvectory.jsonassertify
Result of a .
JSONCompareResult() - Constructor for class com.unitvectory.jsonassertify.JSONCompareResult
Constructs a new JSONCompareResult.
JSONCompareUtil - Class in com.unitvectory.jsonassertify.comparator
Utility class that contains Json manipulation methods.
JSONParser - Class in com.unitvectory.jsonassertify
Simple JSON parsing utility.

L

LENIENT - Enum constant in enum com.unitvectory.jsonassertify.JSONCompareMode
Lenient checking.
LocationAwareValueMatcher<T> - Interface in com.unitvectory.jsonassertify
A ValueMatcher extension that provides location in form of prefix to the equals method.

M

matches(Object, Object) - Method in class com.unitvectory.jsonassertify.Customization
Deprecated.
matches(String, Object, Object, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.Customization
Return true if actual value matches expected value using this Customization's comparator.
missing(String, Object) - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Identify the missing field

N

NON_EXTENSIBLE - Enum constant in enum com.unitvectory.jsonassertify.JSONCompareMode
Non-extensible checking.

P

parseJSON(String) - Static method in class com.unitvectory.jsonassertify.JSONParser
Takes a JSON string and returns either a JSONObject or JSONArray, depending on whether the string represents an object or an array.
passed() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Did the comparison pass?

Q

qualify(String, String) - Static method in class com.unitvectory.jsonassertify.comparator.JSONCompareUtil
Qualifies the given key with the given prefix.

R

recursivelyCompareJSONArray(String, JSONArray, JSONArray, JSONCompareResult) - Method in class com.unitvectory.jsonassertify.comparator.AbstractComparator
Compares JSON object provided to the expected JSON object using provided comparator, and returns the results of the comparison.
RegularExpressionValueMatcher<T> - Class in com.unitvectory.jsonassertify
A JSONassert value matcher that matches actual value to regular expression.
RegularExpressionValueMatcher() - Constructor for class com.unitvectory.jsonassertify.RegularExpressionValueMatcher
Create RegularExpressionValueMatcher in which the pattern the actual value must match with be specified dynamically from the expected string passed to this matcher in the equals method.
RegularExpressionValueMatcher(String) - Constructor for class com.unitvectory.jsonassertify.RegularExpressionValueMatcher
Create RegularExpressionValueMatcher with specified pattern.

S

STRICT - Enum constant in enum com.unitvectory.jsonassertify.JSONCompareMode
Strict checking.
STRICT_ORDER - Enum constant in enum com.unitvectory.jsonassertify.JSONCompareMode
Strict order checking.

T

toString() - Method in class com.unitvectory.jsonassertify.JSONCompareResult
 

U

unexpected(String, Object) - Method in class com.unitvectory.jsonassertify.JSONCompareResult
Identify unexpected field

V

ValueMatcher<T> - Interface in com.unitvectory.jsonassertify
Represents a value matcher that can compare two objects for equality.
ValueMatcherException - Exception in com.unitvectory.jsonassertify
Exception that may be thrown by ValueMatcher subclasses to provide more detail on why matches method failed.
ValueMatcherException(String, String, String) - Constructor for exception com.unitvectory.jsonassertify.ValueMatcherException
Create new ValueMatcherException
ValueMatcherException(String, Throwable, String, String) - Constructor for exception com.unitvectory.jsonassertify.ValueMatcherException
Create new ValueMatcherException
valueOf(String) - Static method in enum com.unitvectory.jsonassertify.JSONCompareMode
Returns the enum constant of this type with the specified name.
values() - Static method in enum com.unitvectory.jsonassertify.JSONCompareMode
Returns an array containing the constants of this enum type, in the order they are declared.

W

withExtensible(boolean) - Method in enum com.unitvectory.jsonassertify.JSONCompareMode
Get the equivalent JSONCompareMode with or without extensibility.
withStrictOrdering(boolean) - Method in enum com.unitvectory.jsonassertify.JSONCompareMode
Get the equivalent JSONCompareMode with or without strict ordering.
A C D E F G H I J L M N P Q R S T U V W 
All Classes and Interfaces|All Packages|Serialized Form